"""la_chariotte URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/4.1/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""

from django.contrib import admin
from django.contrib.auth.views import (
    PasswordResetCompleteView,
    PasswordResetConfirmView,
    PasswordResetDoneView,
)
from django.urls import include, path
from django.views.generic.base import TemplateView

from la_chariotte import settings
from la_chariotte.order.views import JoinGroupedOrderView

urlpatterns = [
    path("admin/", admin.site.urls),
    path("commande/", include("la_chariotte.order.urls")),
    path("comptes/", include("la_chariotte.accounts.urls")),
    # Some paths for accounts are easier to leave here
    # - PasswordResetView sends the mail
    # - PasswordResetDoneView shows a success message for the above
    # - PasswordResetConfirmView checks the link the user clicked and
    #   prompts for a new password
    # - PasswordResetCompleteView shows a success message for the above
    path(
        "comptes/reinitialisation/<uidb64>/<token>/",
        PasswordResetConfirmView.as_view(),
        name="password_reset_confirm",
    ),
    path(
        "comptes/reinitialisation/mail-envoyé/",
        PasswordResetDoneView.as_view(),
        name="password_reset_done",
    ),
    path(
        "comptes/reinitialisation/terminé/",
        PasswordResetCompleteView.as_view(),
        name="password_reset_complete",
    ),
    path(
        "",
        JoinGroupedOrderView.as_view(template_name="dashboard.html"),
        name="dashboard",
    ),
    path(
        "mode-d-emploi",
        TemplateView.as_view(template_name="help/notice.html"),
        name="notice",
    ),
    path(
        "mentions-legales",
        TemplateView.as_view(
            template_name="help/legal_notice.html",
            extra_context={
                "gitlab": settings.GITLAB_LINK,
                "mail": settings.CONTACT_MAIL,
            },
        ),
        name="legal_notice",
    ),
    path(
        "la-chariotte-c-est-quoi",
        TemplateView.as_view(
            template_name="help/about_chariotte.html",
            extra_context={
                "gitlab": settings.GITLAB_LINK,
                "mail": settings.CONTACT_MAIL,
            },
        ),
        name="about_chariotte",
    ),
]
